==> plasma_2.3.0.tar.gz: plasma_2.3.0/timing/time_zpotri_tile.c <==
/**
 *
 * @precisions normal z -> c d s
 *
 **/
#define _TYPE  PLASMA_Complex64_t
#define _PREC  double
#define _LAMCH LAPACKE_dlamch_work

#define _NAME  "PLASMA_zpotri_Tile"
/* See Lawn 41 page 120 */
#define _FMULS (n * (double)(1.0 / 2.0 * n + 1.5) * n)
#define _FADDS (n * (double)(1.0 / 2.0 * n - 0.5) * n)

#include "./timing.c"

static int
RunTest(int *iparam, double *dparam, real_Double_t *t_) 
{
    PLASMA_Complex64_t *AT;
    real_Double_t       t;
    PLASMA_desc        *descA;
    int nb, nb2, nt;
    int n     = iparam[TIMING_N];
    int check = iparam[TIMING_CHECK];
    PLASMA_enum uplo = PlasmaLower;

    /* Initialize Plasma */ 
    PLASMA_Init( iparam[TIMING_THRDNBR] );
    if ( iparam[TIMING_SCHEDULER] )
        PLASMA_Set(PLASMA_SCHEDULING_MODE, PLASMA_DYNAMIC_SCHEDULING );
    else
        PLASMA_Set(PLASMA_SCHEDULING_MODE, PLASMA_STATIC_SCHEDULING );

    /*if ( !iparam[TIMING_AUTOTUNING] ) {*/
        PLASMA_Disable(PLASMA_AUTOTUNING);
        PLASMA_Set(PLASMA_TILE_SIZE,        iparam[TIMING_NB] );
    /* } else { */
    /*     PLASMA_Get(PLASMA_TILE_SIZE,        &iparam[TIMING_NB] ); */
    /* }  */
    nb  = iparam[TIMING_NB];
    nb2 = nb * nb;
    nt  = n / nb + ((n % nb == 0) ? 0 : 1);
    
    /* Allocate Data */
    AT = (PLASMA_Complex64_t *)malloc(nt*nt*nb2*sizeof(PLASMA_Complex64_t));

    /* Check if unable to allocate memory */
    if ( !AT ){
        printf("Out of Memory \n ");
        exit(0);
    }

    /* Initialiaze Data */
    PLASMA_Desc_Create(&descA, AT, PlasmaComplexDouble, nb, nb, nb*nb, n, n, 0, 0, n, n);
    PLASMA_zplghe_Tile(descA, ISEED);

    /* Save AT in lapack layout for check */
    if ( check ) {
    }

    /* PLASMA ZPOTRF / ZTRTRI / ZLAUUM  */
    {
      PLASMA_sequence *sequence = NULL;
      PLASMA_request request[2] = { PLASMA_REQUEST_INITIALIZER, 
                                    PLASMA_REQUEST_INITIALIZER };

      PLASMA_Sequence_Create(&sequence);

      t = -cWtime();
      PLASMA_zpotrf_Tile_Async(uplo, descA, sequence, &request[0]);
      PLASMA_zpotri_Tile_Async(uplo, descA, sequence, &request[1]);
      PLASMA_Sequence_Wait(sequence);
      t += cWtime();
      *t_ = t;

      PLASMA_Sequence_Destroy(sequence);
    }


    /* Check the solution */
    if ( check )
    {
        dparam[TIMING_ANORM] = 0.0;
        dparam[TIMING_XNORM] = 0.0;
        dparam[TIMING_BNORM] = 0.0;
        dparam[TIMING_RES]   = 0.0;
    }

    PLASMA_Desc_Destroy(&descA);
    PLASMA_Finalize();
    free(AT);

    return 0;
}

==> plasma_2.3.1.tar.gz: plasma_2.3.1/timing/time_zpotri_tile.c <==
/**
 *
 * @precisions normal z -> c d s
 *
 **/
#define _TYPE  PLASMA_Complex64_t
#define _PREC  double
#define _LAMCH LAPACKE_dlamch_work

#define _NAME  "PLASMA_zpotri_Tile"
/* See Lawn 41 page 120 */
#define _FMULS (n * (double)(1.0 / 2.0 * n + 1.5) * n)
#define _FADDS (n * (double)(1.0 / 2.0 * n - 0.5) * n)

#include "./timing.c"

static int
RunTest(int *iparam, double *dparam, real_Double_t *t_) 
{
    PLASMA_Complex64_t *AT;
    real_Double_t       t;
    PLASMA_desc        *descA;
    int nb, nb2, nt;
    int n     = iparam[TIMING_N];
    int check = iparam[TIMING_CHECK];
    PLASMA_enum uplo = PlasmaLower;

    /* Initialize Plasma */ 
    PLASMA_Init( iparam[TIMING_THRDNBR] );
    if ( iparam[TIMING_SCHEDULER] )
        PLASMA_Set(PLASMA_SCHEDULING_MODE, PLASMA_DYNAMIC_SCHEDULING );
    else
        PLASMA_Set(PLASMA_SCHEDULING_MODE, PLASMA_STATIC_SCHEDULING );

    /*if ( !iparam[TIMING_AUTOTUNING] ) {*/
        PLASMA_Disable(PLASMA_AUTOTUNING);
        PLASMA_Set(PLASMA_TILE_SIZE,        iparam[TIMING_NB] );
    /* } else { */
    /*     PLASMA_Get(PLASMA_TILE_SIZE,        &iparam[TIMING_NB] ); */
    /* }  */
    nb  = iparam[TIMING_NB];
    nb2 = nb * nb;
    nt  = n / nb + ((n % nb == 0) ? 0 : 1);
    
    /* Allocate Data */
    AT = (PLASMA_Complex64_t *)malloc(nt*nt*nb2*sizeof(PLASMA_Complex64_t));

    /* Check if unable to allocate memory */
    if ( !AT ){
        printf("Out of Memory \n ");
        exit(0);
    }

    /* Initialiaze Data */
    PLASMA_Desc_Create(&descA, AT, PlasmaComplexDouble, nb, nb, nb*nb, n, n, 0, 0, n, n);
    PLASMA_zplghe_Tile( (double)n, descA, 51 );

    /* Save AT in lapack layout for check */
    if ( check ) {
    }

    /* PLASMA ZPOTRF / ZTRTRI / ZLAUUM  */
    {
      PLASMA_sequence *sequence = NULL;
      PLASMA_request request[2] = { PLASMA_REQUEST_INITIALIZER, 
                                    PLASMA_REQUEST_INITIALIZER };

      PLASMA_Sequence_Create(&sequence);

      t = -cWtime();
      PLASMA_zpotrf_Tile_Async(uplo, descA, sequence, &request[0]);
      PLASMA_zpotri_Tile_Async(uplo, descA, sequence, &request[1]);
      PLASMA_Sequence_Wait(sequence);
      t += cWtime();
      *t_ = t;

      PLASMA_Sequence_Destroy(sequence);
    }


    /* Check the solution */
    if ( check )
    {
        dparam[TIMING_ANORM] = 0.0;
        dparam[TIMING_XNORM] = 0.0;
        dparam[TIMING_BNORM] = 0.0;
        dparam[TIMING_RES]   = 0.0;
    }

    PLASMA_Desc_Destroy(&descA);
    PLASMA_Finalize();
    free(AT);

    return 0;
}
